==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractingvolumedetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包月度报量及申请报告月度子表
 * 
 * @author generator
 * 
 */
@TableName("ejc_middlemeasurement_subcontractingvolumedetail")
public class SubcontractingvolumedetailEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "mid")
	private java.lang.Long mid; // 主表id
	@TableField(value = "bill_state")
	private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	@TableField(value = "sort")
	private java.lang.String sort; // 序号
	@TableField(value = "bill_code")
	private java.lang.String billCode; // 清单编号
	@TableField(value = "bill_name")
	private java.lang.String billName; // 清单项目名称
	@TableField(value = "unit")
	private java.lang.String unit; // 单位
	@TableField(value = "quantity")
	private java.math.BigDecimal quantity; // 数量
	@TableField(value = "unitprice")
	private java.math.BigDecimal unitprice; // 除税单价
	@TableField(value = "tax_unitprice")
	private java.math.BigDecimal taxUnitprice; // 含税单价
	@TableField(value = "amounts")
	private java.math.BigDecimal amounts; // 除税金额
	@TableField(value = "tax_amounts")
	private java.math.BigDecimal taxAmounts; // 含税金额
	@TableField(value = "cumulative_quantity")
	private java.math.BigDecimal cumulativeQuantity; // 数量
	@TableField(value = "cumulative_amounts")
	private java.math.BigDecimal cumulativeAmounts; // 除税金额
	@TableField(value = "cumulative_tax_amounts")
	private java.math.BigDecimal cumulativeTaxAmounts; // 含税金额
	@TableField(value = "examine_quantity")
	private java.math.BigDecimal examineQuantity; // 数量
	@TableField(value = "examine_unitprice")
	private java.math.BigDecimal examineUnitprice; // 除税单价
	@TableField(value = "examine_tax_unitprice")
	private java.math.BigDecimal examineTaxUnitprice; // 含税单价
	@TableField(value = "examine_amounts")
	private java.math.BigDecimal examineAmounts; // 除税金额
	@TableField(value = "examine_tax_amounts")
	private java.math.BigDecimal examineTaxAmounts; // 含税金额
	@TableField(value = "examine_cumulative_quantity")
	private java.math.BigDecimal examineCumulativeQuantity; // 数量
	@TableField(value = "examine_cumulative_amounts")
	private java.math.BigDecimal examineCumulativeAmounts; // 除税金额
	@TableField(value = "examine_cumulative_tax_amounts")
	private java.math.BigDecimal examineCumulativeTaxAmounts; // 含税金额
	@TableField(value = "source")
	private java.lang.Integer source; // 来源
	@TableField(value = "memo")
	private java.lang.String memo; // 备注

	/**
	 * 主表id
	 */
	public java.lang.Long getMid() {
		return mid;
	}

	/**
	 * 主表id
	 */
	public void setMid(java.lang.Long mid) {
		this.mid = mid;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public java.lang.Integer getBillState() {
		return billState;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public void setBillState(java.lang.Integer billState) {
		this.billState = billState;
	}

	/**
	 * 序号
	 */
	public java.lang.String getSort() {
		return sort;
	}

	/**
	 * 序号
	 */
	public void setSort(java.lang.String sort) {
		this.sort = sort;
	}

	/**
	 * 清单编号
	 */
	public java.lang.String getBillCode() {
		return billCode;
	}

	/**
	 * 清单编号
	 */
	public void setBillCode(java.lang.String billCode) {
		this.billCode = billCode;
	}

	/**
	 * 清单项目名称
	 */
	public java.lang.String getBillName() {
		return billName;
	}

	/**
	 * 清单项目名称
	 */
	public void setBillName(java.lang.String billName) {
		this.billName = billName;
	}

	/**
	 * 单位
	 */
	public java.lang.String getUnit() {
		return unit;
	}

	/**
	 * 单位
	 */
	public void setUnit(java.lang.String unit) {
		this.unit = unit;
	}

	/**
	 * 数量
	 */
	public java.math.BigDecimal getQuantity() {
		return quantity;
	}

	/**
	 * 数量
	 */
	public void setQuantity(java.math.BigDecimal quantity) {
		this.quantity = quantity;
	}

	/**
	 * 除税单价
	 */
	public java.math.BigDecimal getUnitprice() {
		return unitprice;
	}

	/**
	 * 除税单价
	 */
	public void setUnitprice(java.math.BigDecimal unitprice) {
		this.unitprice = unitprice;
	}

	/**
	 * 含税单价
	 */
	public java.math.BigDecimal getTaxUnitprice() {
		return taxUnitprice;
	}

	/**
	 * 含税单价
	 */
	public void setTaxUnitprice(java.math.BigDecimal taxUnitprice) {
		this.taxUnitprice = taxUnitprice;
	}

	/**
	 * 除税金额
	 */
	public java.math.BigDecimal getAmounts() {
		return amounts;
	}

	/**
	 * 除税金额
	 */
	public void setAmounts(java.math.BigDecimal amounts) {
		this.amounts = amounts;
	}

	/**
	 * 含税金额
	 */
	public java.math.BigDecimal getTaxAmounts() {
		return taxAmounts;
	}

	/**
	 * 含税金额
	 */
	public void setTaxAmounts(java.math.BigDecimal taxAmounts) {
		this.taxAmounts = taxAmounts;
	}

	/**
	 * 数量
	 */
	public java.math.BigDecimal getCumulativeQuantity() {
		return cumulativeQuantity;
	}

	/**
	 * 数量
	 */
	public void setCumulativeQuantity(java.math.BigDecimal cumulativeQuantity) {
		this.cumulativeQuantity = cumulativeQuantity;
	}

	/**
	 * 除税金额
	 */
	public java.math.BigDecimal getCumulativeAmounts() {
		return cumulativeAmounts;
	}

	/**
	 * 除税金额
	 */
	public void setCumulativeAmounts(java.math.BigDecimal cumulativeAmounts) {
		this.cumulativeAmounts = cumulativeAmounts;
	}

	/**
	 * 含税金额
	 */
	public java.math.BigDecimal getCumulativeTaxAmounts() {
		return cumulativeTaxAmounts;
	}

	/**
	 * 含税金额
	 */
	public void setCumulativeTaxAmounts(java.math.BigDecimal cumulativeTaxAmounts) {
		this.cumulativeTaxAmounts = cumulativeTaxAmounts;
	}

	/**
	 * 数量
	 */
	public java.math.BigDecimal getExamineQuantity() {
		return examineQuantity;
	}

	/**
	 * 数量
	 */
	public void setExamineQuantity(java.math.BigDecimal examineQuantity) {
		this.examineQuantity = examineQuantity;
	}

	/**
	 * 除税单价
	 */
	public java.math.BigDecimal getExamineUnitprice() {
		return examineUnitprice;
	}

	/**
	 * 除税单价
	 */
	public void setExamineUnitprice(java.math.BigDecimal examineUnitprice) {
		this.examineUnitprice = examineUnitprice;
	}

	/**
	 * 含税单价
	 */
	public java.math.BigDecimal getExamineTaxUnitprice() {
		return examineTaxUnitprice;
	}

	/**
	 * 含税单价
	 */
	public void setExamineTaxUnitprice(java.math.BigDecimal examineTaxUnitprice) {
		this.examineTaxUnitprice = examineTaxUnitprice;
	}

	/**
	 * 除税金额
	 */
	public java.math.BigDecimal getExamineAmounts() {
		return examineAmounts;
	}

	/**
	 * 除税金额
	 */
	public void setExamineAmounts(java.math.BigDecimal examineAmounts) {
		this.examineAmounts = examineAmounts;
	}

	/**
	 * 含税金额
	 */
	public java.math.BigDecimal getExamineTaxAmounts() {
		return examineTaxAmounts;
	}

	/**
	 * 含税金额
	 */
	public void setExamineTaxAmounts(java.math.BigDecimal examineTaxAmounts) {
		this.examineTaxAmounts = examineTaxAmounts;
	}

	/**
	 * 数量
	 */
	public java.math.BigDecimal getExamineCumulativeQuantity() {
		return examineCumulativeQuantity;
	}

	/**
	 * 数量
	 */
	public void setExamineCumulativeQuantity(java.math.BigDecimal examineCumulativeQuantity) {
		this.examineCumulativeQuantity = examineCumulativeQuantity;
	}

	/**
	 * 除税金额
	 */
	public java.math.BigDecimal getExamineCumulativeAmounts() {
		return examineCumulativeAmounts;
	}

	/**
	 * 除税金额
	 */
	public void setExamineCumulativeAmounts(java.math.BigDecimal examineCumulativeAmounts) {
		this.examineCumulativeAmounts = examineCumulativeAmounts;
	}

	/**
	 * 含税金额
	 */
	public java.math.BigDecimal getExamineCumulativeTaxAmounts() {
		return examineCumulativeTaxAmounts;
	}

	/**
	 * 含税金额
	 */
	public void setExamineCumulativeTaxAmounts(java.math.BigDecimal examineCumulativeTaxAmounts) {
		this.examineCumulativeTaxAmounts = examineCumulativeTaxAmounts;
	}

	/**
	 * 来源
	 */
	public java.lang.Integer getSource() {
		return source;
	}

	/**
	 * 来源
	 */
	public void setSource(java.lang.Integer source) {
		this.source = source;
	}

	public java.lang.String getMemo() {
		return memo;
	}

	public void setMemo(java.lang.String memo) {
		this.memo = memo;
	}
}

==> ejc-middlemeasurement-impl-3.0.0-20220902.091149-128-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractingvolumedetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包月度报量及申请报告月度子表
 * 
 * @author generator
 * 
 */
@TableName("ejc_middlemeasurement_subcontractingvolumedetail")
public class SubcontractingvolumedetailEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "mid")
	private java.lang.Long mid; // 主表id
	@TableField(value = "bill_state")
	private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	@TableField(value = "sort")
	private java.lang.String sort; // 序号
	@TableField(value = "subitem_code")
	private java.lang.String subitemCode; // 清单编号
	@TableField(value = "subitem_name")
	private java.lang.String subitemName; // 清单项目名称
	@TableField(value = "unit")
	private java.lang.String unit; // 单位
	@TableField(value = "quantity")
	private java.math.BigDecimal quantity; // 数量
	@TableField(value = "unitprice")
	private java.math.BigDecimal unitprice; // 除税单价
	@TableField(value = "tax_unitprice")
	private java.math.BigDecimal taxUnitprice; // 含税单价
	@TableField(value = "amounts")
	private java.math.BigDecimal amounts; // 除税金额
	@TableField(value = "tax_amounts")
	private java.math.BigDecimal taxAmounts; // 含税金额
	@TableField(value = "cumulative_quantity")
	private java.math.BigDecimal cumulativeQuantity; // 数量
	@TableField(value = "cumulative_amounts")
	private java.math.BigDecimal cumulativeAmounts; // 除税金额
	@TableField(value = "cumulative_tax_amounts")
	private java.math.BigDecimal cumulativeTaxAmounts; // 含税金额
	@TableField(value = "examine_quantity")
	private java.math.BigDecimal examineQuantity; // 数量（项目部审核：本期）
	@TableField(value = "examine_unitprice")
	private java.math.BigDecimal examineUnitprice; // 除税单价
	@TableField(value = "examine_tax_unitprice")
	private java.math.BigDecimal examineTaxUnitprice; // 含税单价
	@TableField(value = "examine_amounts")
	private java.math.BigDecimal examineAmounts; // 除税金额
	@TableField(value = "examine_tax_amounts")
	private java.math.BigDecimal examineTaxAmounts; // 含税金额
	@TableField(value = "examine_cumulative_quantity")
	private java.math.BigDecimal examineCumulativeQuantity; // 数量
	@TableField(value = "examine_cumulative_amounts")
	private java.math.BigDecimal examineCumulativeAmounts; // 除税金额
	@TableField(value = "examine_cumulative_tax_amounts")
	private java.math.BigDecimal examineCumulativeTaxAmounts; // 含税金额
	@TableField(value = "source")
	private java.lang.String source; // 来源
	@TableField(value = "memo")
	private java.lang.String memo; // 备注
	@TableField(value="tid")
	private java.lang.String tid;
	@TableField(value="tpid")
	private java.lang.String tpid;
	@TableField(value="innercode")
	private String innercode; // 内码
	@TableField(value="contract_id")
	private java.lang.Long contractId; // 主表合同id

	/**
	 * 主表id
	 */
	public java.lang.Long getMid() {
		return mid;
	}

	/**
	 * 主表id
	 */
	public void setMid(java.lang.Long mid) {
		this.mid = mid;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public java.lang.Integer getBillState() {
		return billState;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public void setBillState(java.lang.Integer billState) {
		this.billState = billState;
	}

	/**
	 * 序号
	 */
	public java.lang.String getSort() {
		return sort;
	}

	/**
	 * 序号
	 */
	public void setSort(java.lang.String sort) {
		this.sort = sort;
	}

	public String getSubitemCode() {
		return subitemCode;
	}

	public void setSubitemCode(String subitemCode) {
		this.subitemCode = subitemCode;
	}

	public String getSubitemName() {
		return subitemName;
	}

	public void setSubitemName(String subitemName) {
		this.subitemName = subitemName;
	}

	/**
	 * 单位
	 */
	public java.lang.String getUnit() {
		return unit;
	}

	/**
	 * 单位
	 */
	public void setUnit(java.lang.String unit) {
		this.unit = unit;
	}

	/**
	 * 数量
	 */
	public java.math.BigDecimal getQuantity() {
		return quantity;
	}

	/**
	 * 数量
	 */
	public void setQuantity(java.math.BigDecimal quantity) {
		this.quantity = quantity;
	}

	/**
	 * 除税单价
	 */
	public java.math.BigDecimal getUnitprice() {
		return unitprice;
	}

	/**
	 * 除税单价
	 */
	public void setUnitprice(java.math.BigDecimal unitprice) {
		this.unitprice = unitprice;
	}

	/**
	 * 含税单价
	 */
	public java.math.BigDecimal getTaxUnitprice() {
		return taxUnitprice;
	}

	/**
	 * 含税单价
	 */
	public void setTaxUnitprice(java.math.BigDecimal taxUnitprice) {
		this.taxUnitprice = taxUnitprice;
	}

	/**
	 * 除税金额
	 */
	public java.math.BigDecimal getAmounts() {
		return amounts;
	}

	/**
	 * 除税金额
	 */
	public void setAmounts(java.math.BigDecimal amounts) {
		this.amounts = amounts;
	}

	/**
	 * 含税金额
	 */
	public java.math.BigDecimal getTaxAmounts() {
		return taxAmounts;
	}

	/**
	 * 含税金额
	 */
	public void setTaxAmounts(java.math.BigDecimal taxAmounts) {
		this.taxAmounts = taxAmounts;
	}

	/**
	 * 数量
	 */
	public java.math.BigDecimal getCumulativeQuantity() {
		return cumulativeQuantity;
	}

	/**
	 * 数量
	 */
	public void setCumulativeQuantity(java.math.BigDecimal cumulativeQuantity) {
		this.cumulativeQuantity = cumulativeQuantity;
	}

	/**
	 * 除税金额
	 */
	public java.math.BigDecimal getCumulativeAmounts() {
		return cumulativeAmounts;
	}

	/**
	 * 除税金额
	 */
	public void setCumulativeAmounts(java.math.BigDecimal cumulativeAmounts) {
		this.cumulativeAmounts = cumulativeAmounts;
	}

	/**
	 * 含税金额
	 */
	public java.math.BigDecimal getCumulativeTaxAmounts() {
		return cumulativeTaxAmounts;
	}

	/**
	 * 含税金额
	 */
	public void setCumulativeTaxAmounts(java.math.BigDecimal cumulativeTaxAmounts) {
		this.cumulativeTaxAmounts = cumulativeTaxAmounts;
	}

	/**
	 * 数量
	 */
	public java.math.BigDecimal getExamineQuantity() {
		return examineQuantity;
	}

	/**
	 * 数量
	 */
	public void setExamineQuantity(java.math.BigDecimal examineQuantity) {
		this.examineQuantity = examineQuantity;
	}

	/**
	 * 除税单价
	 */
	public java.math.BigDecimal getExamineUnitprice() {
		return examineUnitprice;
	}

	/**
	 * 除税单价
	 */
	public void setExamineUnitprice(java.math.BigDecimal examineUnitprice) {
		this.examineUnitprice = examineUnitprice;
	}

	/**
	 * 含税单价
	 */
	public java.math.BigDecimal getExamineTaxUnitprice() {
		return examineTaxUnitprice;
	}

	/**
	 * 含税单价
	 */
	public void setExamineTaxUnitprice(java.math.BigDecimal examineTaxUnitprice) {
		this.examineTaxUnitprice = examineTaxUnitprice;
	}

	/**
	 * 除税金额
	 */
	public java.math.BigDecimal getExamineAmounts() {
		return examineAmounts;
	}

	/**
	 * 除税金额
	 */
	public void setExamineAmounts(java.math.BigDecimal examineAmounts) {
		this.examineAmounts = examineAmounts;
	}

	/**
	 * 含税金额
	 */
	public java.math.BigDecimal getExamineTaxAmounts() {
		return examineTaxAmounts;
	}

	/**
	 * 含税金额
	 */
	public void setExamineTaxAmounts(java.math.BigDecimal examineTaxAmounts) {
		this.examineTaxAmounts = examineTaxAmounts;
	}

	/**
	 * 数量
	 */
	public java.math.BigDecimal getExamineCumulativeQuantity() {
		return examineCumulativeQuantity;
	}

	/**
	 * 数量
	 */
	public void setExamineCumulativeQuantity(java.math.BigDecimal examineCumulativeQuantity) {
		this.examineCumulativeQuantity = examineCumulativeQuantity;
	}

	/**
	 * 除税金额
	 */
	public java.math.BigDecimal getExamineCumulativeAmounts() {
		return examineCumulativeAmounts;
	}

	/**
	 * 除税金额
	 */
	public void setExamineCumulativeAmounts(java.math.BigDecimal examineCumulativeAmounts) {
		this.examineCumulativeAmounts = examineCumulativeAmounts;
	}

	/**
	 * 含税金额
	 */
	public java.math.BigDecimal getExamineCumulativeTaxAmounts() {
		return examineCumulativeTaxAmounts;
	}

	/**
	 * 含税金额
	 */
	public void setExamineCumulativeTaxAmounts(java.math.BigDecimal examineCumulativeTaxAmounts) {
		this.examineCumulativeTaxAmounts = examineCumulativeTaxAmounts;
	}

	/**
	 * 来源
	 */
	public java.lang.String getSource() {
		return source;
	}

	/**
	 * 来源
	 */
	public void setSource(java.lang.String source) {
		this.source = source;
	}

	public java.lang.String getMemo() {
		return memo;
	}

	public void setMemo(java.lang.String memo) {
		this.memo = memo;
	}

	public String getTid() {
		return tid;
	}

	public void setTid(String tid) {
		this.tid = tid;
	}

	public String getTpid() {
		return tpid;
	}

	public void setTpid(String tpid) {
		this.tpid = tpid;
	}

	public String getInnercode() {
		return innercode;
	}

	public void setInnercode(String innercode) {
		this.innercode = innercode;
	}

	public Long getContractId() {
		return contractId;
	}

	public void setContractId(Long contractId) {
		this.contractId = contractId;
	}
}
